@@ -11,6 +11,9 @@ IBIS_SUBSTRAIT_OP_MAPPING = {
     "Asin": "asin",
     "Atan": "atan",
     "Atan2": "atan2",
+    "BitAnd": "bitwise_and",
+    "BitOr": "bitwise_or",
+    "BitXor": "bitwise_xor",
     "Between": "between",
     "Capitalize": "capitalize",
     "Ceil": "ceil",
